@@ -12,7 +12,7 @@ from r3sponse import r3sponse
 # source.
 ALIAS = "netw0rk"
 SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
-OS = syst3m.defaults.operating_system(supported=["osx", "linux"])
+OS = syst3m.defaults.operating_system(supported=["macos", "linux"])
 syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
@@ -21,7 +21,7 @@ GROUP = "root"
 HOME_BASE = "/home/"
 HOME = f"/home/{os.environ.get('USER')}/"
 MEDIA = f"/media/{os.environ.get('USER')}/"
-if OS in ["osx"]: 
+if OS in ["macos"]: 
 	HOME_BASE = "/Users/"
 	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
